<?php

namespace ScottK\Lib\Database;

use PDO;

class Database
{
	protected static $connection = null;

	protected static function assignments($fields)
	{
		return implode(', ', array_map(function ($col) {
			return "$col = ?";
		}, array_keys($fields)));
	}

	protected static function makeConnection()
	{
		if (! self::$connection)
		{
			$config = config('database');
			self::$connection = new PDO($config->driver . ':'
				. 'host=' . $config->host . ';'
				. 'port=' . $config->port . ';'
				. 'dbname=' . $config->catalog,
				$config->user,
				$config->password
			);
		}
		return self::$connection;
	}

	protected static function conditional($fields)
	{
		return implode(' and ', array_map(function ($col) {
			return "$col = ?";
		}, array_keys($fields)));
	}

	public static function insert($table, array $fields)
	{
		$fieldString = self::assignments($fields);
		return self::query("insert into $table set $fieldString", array_values($fields));
	}

	public static function query($query, array $data = [])
	{
		$statement = self::makeConnection()->prepare($query);
		$statement->execute($data);
		return $statement->fetchAll(DATABASE_FETCH_DEFAULT);
	}

	public static function update($table, array $newFieldValues, array $whereValues)
	{
		$assignments = self::assignments($newFieldValues);
		$conditionals = self::conditional($whereValues);
		$data = array_merge(array_values($newFieldValues), array_values($whereValues));
		return self::query("update $table set $assignments where $conditionals", $data);
	}
}