<?php

namespace ScottK\Lib\Templates;

class Template
{
	const TEMPLATE_PATH = APP_RELATIVE_PATH . 'templates';
	const TEMPLATE_CACHE_PATH = APP_RELATIVE_PATH . 'template-cache';
	static $config = null;
	static $data = [];

	static function escapeVariable($name)
	{
		echo self::escapeString(self::get($name));
	}

	static function escapeString($string)
	{
		return htmlentities($string);
	}

	static function get($name)
	{
		return array_key_exists($name, self::$data)
		? self::$data[$name]
		: '';
	}

	static function getCacheFilename($name):string
	{
		return md5($name);
	}

	static function getCacheFullPath($name):string
	{
		return codePath([self::TEMPLATE_CACHE_PATH, self::getCacheFilename($name)]);
	}

	static function loadConfig():object
	{
		if (! self::$config)
		{
			self::$config = config('template');
		}
		return self::$config;
	}

	static function loadFromCache($fullPath):bool
	{
		if (file_exists($fullPath))
		{
			readfile($fullPath);
			return true;
		}
			return false;
	}

	static function load($template, array $data = [])
	{
		if (self::loadConfig()->cache && self::get('cache'))
		{
			$fullCacheFilePath = self::getCacheFullPath($template);
			if (false === self::loadFromCache($fullCacheFilePath))
			{
				ob_start();
				self::renderTemplate($template);
				$contents = ob_get_contents();
				self::saveCache($fullCacheFilePath, $contents);
				ob_end_flush();
			}
		}
		else
		{
			self::renderTemplate($template, $data);
		}
	}

	static function renderTemplate($template, array $data = [])
	{
		$combinedArray = array_merge(self::$data, $data);
		extract($combinedArray);
		includeCode([self::TEMPLATE_PATH, $template]);
	}

	static function saveCache($fullPath, $content)
	{
		file_put_contents($fullPath, $content);
	}

	static function set($name, $data = '')
	{
		self::$data[$name] = $data;
	}

	static function urlEncode($name)
	{
		echo urlencode(self::get($name));
	}
}