<?php

define('MAIL_LIBRARY_PATH', THIRD_PARTY_RELATIVE_PATH . 'PHPMailer-master' . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR);

requireCode(MAIL_LIBRARY_PATH . 'Exception');
requireCode(MAIL_LIBRARY_PATH . 'PHPMailer');
requireCode(MAIL_LIBRARY_PATH . 'SMTP');

use PHPMailer\PHPMailer\Exception;
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\SMTP;

function buildHtmlMessage(object $message)
{
	$content = '';
	foreach ($message as $name => $value)
	{
		$content .= '<b>' . htmlentities($name) . '</b>' . "\n";
		$content .= htmlentities($value) . "\n\n";
	}
	return implode("\n", [
		'<!doctype html>',
		'<html>',
			'<body>',
				'<table border="0" cellpadding="0" cellspacing="0">',
					'<tr>',
						'<td>',
							'<pre>' . $content . '</pre>',
						'</td>',
					'</tr>',
				'</table>',
			'</body>',
		'</html>'
	]);
}

function sendNotification($subject, $message, $fromEmail = '', $fromName = '')
{
	try
	{
		$mailConfig = config('email');
		$mail = new PHPMailer(true);
		if ('true' === $mailConfig->debug)
		{
			$mail->SMTPDebug = SMTP::DEBUG_CONNECTION;
		}
		$mail->isSMTP();
		$mail->Host = $mailConfig->smtpServer;
		$mail->SMTPAuth = true;
		$mail->Username = $mailConfig->user;
		$mail->Password = $mailConfig->password;
		$mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
		$mail->Port = $mailConfig->port;

		$mail->setFrom(
			($fromEmail) ? $fromEmail : $mailConfig->notify,
			($fromName) ? $fromName : $mailConfig->notify
		);
		$mail->SMTPOptions = [
			'ssl' => [
				'verify_peer' => false,
				'allow_self_signed' => true,
				'peer_name' => $mailConfig->sslPeerName
			],
		];
		$mail->addAddress($mailConfig->notify);

		$mail->isHTML(true);
		$mail->Subject = $subject;
		$mail->Body = $message;
		$mail->AltBody = strip_tags($message);

		return $mail->send();
	}
	catch (Exception $e)
	{
		throw($e);
	}
}